@@ -1,17 +1,19 @@
 /*
  * config-io.h
  *
- * Copyright (c) 1996 T. J. Wilkinson & Associates, London, UK.
+ * Copyright (c) 1996, 1997
+ *	Transvirtual Technologies, Inc.  All rights reserved.
  *
- * See the file "license.terms" for information on usage and redistribution
- * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
- *
- * Written by Tim Wilkinson <tim@tjwassoc.demon.co.uk>
+ * See the file "license.terms" for information on usage and redistribution 
+ * of this file. 
  */
 
 #ifndef __config_io_h
 #define __config_io_h
 
+#if defined(HAVE_SYS_SELECT_H)
+#include <sys/select.h>
+#endif
 #if defined(HAVE_SYS_SOCKET_H)
 #include <sys/socket.h>
 #endif
@@ -37,7 +39,7 @@
 #if defined(HAVE_DIRENT_H)
 # include <dirent.h>
 # define NAMLEN(dirent) (strlen((dirent)->d_name))
-#else
+#elif defined(HAVE_SYS_NDIR_H) || defined(HAVE_NDIR_H) || defined(HAVE_SYS_DIR_H)
 # define dirent direct
 # define NAMLEN(dirent) ((dirent)->d_namlen)
 # if defined(HAVE_SYS_NDIR_H)
@@ -46,14 +48,9 @@
 # if defined(HAVE_NDIR_H)
 #  include <ndir.h>
 # endif
-#endif
-/* This may nolonger be necessary */
-#if defined(HAVE_SYS_DIR_H)
-#include <sys/dir.h>
-#endif
-
-#if defined(HAVE_DIR_H)
-#include <dir.h>
+# if defined(HAVE_SYS_DIR_H)
+#  include <sys/dir.h>
+# endif
 #endif
 
 #if !defined(S_ISDIR)
@@ -73,4 +70,8 @@
 #define	O_BINARY	0
 #endif
 
+#if !defined(FD_COPY)
+#define	FD_COPY(a, b)	memcpy(b, a, sizeof(*b))
+#endif
+
 #endif
